## Version 0.0.11

This version introduces automatic recording of prompts, improves the recording process, and verifies its functionality. It also includes a cleanup of notebooks and adds loguru as a dependency.

### New Features

- Added automatic recording of prompts (2c956f) (Eric Ma)
- Improved automatic recording of prompts (50779c) (Eric Ma)
- Verified that the recorder works (aa428a) (Eric Ma)
- Added loguru as a dependency (23ee02) (Eric Ma)

### Bug Fixes

- Fixed return type (3986b7) (Eric Ma)

### Other Changes

- Cleaned up notebooks (3c5a74) (Eric Ma)
- Reorganized notebook structure (4bee78) (Eric Ma)
- Enabled context manager for recording prompt-response pairs (e6a8b4) (Eric Ma)
- Settled on a stuff-the-text-into-prompt pattern rather than synthesizing and refining response. This makes things faster (7020d0) (Eric Ma)
- Enabled arbitrary loading of documents, not just text files (e4223c) (Eric Ma)
- Switched to using servable for feynman example (e50e45) (Eric Ma)
- Disabled test mode. A different way to make mock API calls work will be found (7a7beb) (Eric Ma)
- More experiments with llamahub loaders (4b2871) (Eric Ma)

### Deprecations

- No deprecations in this release.
